/*
 * Asterisk -- A telephony toolkit for Linux.
 *
 * Skeleton application
 * 
 * Copyright (C) 1999, Mark Spencer
 *
 * Mark Spencer <markster@linux-support.net>
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License
 */

#include <asterisk/file.h>
#include <asterisk/logger.h>
#include <asterisk/channel.h>
#include <asterisk/pbx.h>
#include <asterisk/module.h>
#include <asterisk/options.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <pthread.h>

static char *tdesc = "Getvar/Setvar Testbench";
static char *app = "gvsvtb";
static char *synopsis = 
"  This is a test bench for ast_variable_set, ast_variable_get ast_variable_get_alloc\n"
"  *************** Do not include this file in the Asterisk code base ******************\n";

STANDARD_LOCAL_USER;

LOCAL_USER_DECL;

static int gvsvtb_exec(struct ast_channel *chan, void *data)
{
	int res=0;
	struct localuser *u;
	
	char *var;
	char workspace[32];

	LOCAL_USER_ADD(u);
	
	
	/* Test channel variable set/get */
	
	ast_verbose(VERBOSE_PREFIX_1 "Test 1: call ast_variable_set and assign a channel variable TESTVAR1 <= TESTVAL1\n");
	if(ast_variable_set(chan, "TESTVAR1", "TESTVAL1")){
		ast_verbose(VERBOSE_PREFIX_1 "Test 1: call to ast_variable_set failed\n");
		goto finished;
	}
	
	var = ast_variable_get(chan, "TESTVAR1", workspace, sizeof(workspace));
	
	if(!var){
		ast_verbose(VERBOSE_PREFIX_1 "Test 1: call to ast_variable_get failed\n");
		goto finished;
	}
	ast_verbose(VERBOSE_PREFIX_1 "Test 1: ast_variable_get returned: %s\n", var);
	
	/* Test builtin retrieve */
	
	ast_verbose(VERBOSE_PREFIX_1 "Test 2: Retrieve CALLERIDNUM builtin variable with ast_variable_get\n");
	var = ast_variable_get(chan, "CALLERIDNUM", workspace, sizeof(workspace));
	
	if(!var){
		ast_verbose(VERBOSE_PREFIX_1 "Test 2: call to ast_variable_get failed\n");
		goto finished;
	}
	ast_verbose(VERBOSE_PREFIX_1 "Test 2: ast_variable_get returned: %s\n", var);
	
	ast_verbose(VERBOSE_PREFIX_1 "Test 3: Retrieve  CHANNEL builtin variable with ast_variable_get_alloc\n");
	var = ast_variable_get_alloc(chan, "CHANNEL");
	if(!var){
		ast_verbose(VERBOSE_PREFIX_1 "Test 3: call to ast_variable_get failed\n");
		goto finished;
	}
	ast_verbose(VERBOSE_PREFIX_1 "Test 3: ast_variable_get returned: %s\n", var);

	
finished:
	LOCAL_USER_REMOVE(u);
	return res;
}

int unload_module(void)
{
	STANDARD_HANGUP_LOCALUSERS;
	return ast_unregister_application(app);
}

int load_module(void)
{
	return ast_register_application(app, gvsvtb_exec, synopsis, tdesc);
}

char *description(void)
{
	return tdesc;
}

int usecount(void)
{
	int res;
	STANDARD_USECOUNT(res);
	return res;
}

char *key()
{
	return ASTERISK_GPL_KEY;
}
